@@ -38,11 +38,12 @@
 #include <stxxl/bits/common/uint_types.h>
 
 using stxxl::uint64;
+using stxxl::internal_size_type;
 using stxxl::external_size_type;
 namespace stream = stxxl::stream;
 
 // 1 GiB ram used by external data structures / 1 MiB block size
-uint64 ram_use = 1024 * 1024 * 1024;
+internal_size_type ram_use = 1024 * 1024 * 1024;
 
 // alphabet data type
 typedef unsigned char alphabet_type;
@@ -274,7 +275,6 @@ public:
         static value_type max_value() { return value_type::max_value(); }
     };
 
-
     /** Check, if last two components of tree quads are equal. */
     template <class quad_type>
     static inline bool quad_eq(const quad_type& a, const quad_type& b)
@@ -300,8 +300,8 @@ public:
         skew_pair_type result;
 
     public:
-        naming(Input& A_, bool& unique_) :
-            A(A_), unique(unique_), lexname(0)
+        naming(Input& A_, bool& unique_)
+            : A(A_), unique(unique_), lexname(0)
         {
             assert(!A.empty());
             unique = true;
@@ -391,7 +391,6 @@ public:
         { return (A.empty() || B.empty()); }
     };
 
-
     /**
      * Collect three characters t_i, t_{i+1}, t_{i+2} beginning at the index
      * i. Since we need at least one unique endcaracter, we free the first
@@ -541,7 +540,6 @@ public:
         { return A.empty(); }
     };
 
-
     /** Create the suffix array from the current sub problem by simple
      *  comparison-based merging.  More precisely: compare characters(out of
      *  text t) and ranks(out of ISA12) of the following constellation:
@@ -712,9 +710,8 @@ public:
         }
     };
 
-
     /** Helper function for computing the size of the 2/3 subproblem. */
-    static inline size_t subp_size(size_t n)
+    static inline size_type subp_size(size_type n)
     {
         return (n / 3) * 2 + ((n % 3) == 2);
     }
@@ -791,7 +788,7 @@ public:
         value_type result;
 
     public:
-        build_sa(S& source_, Mod1& mod_1_, Mod2& mod_2_, size_t a_size, size_t memsize)
+        build_sa(S& source_, Mod1& mod_1_, Mod2& mod_2_, size_type a_size, size_t memsize)
             : source(source_), mod_1(mod_1_), mod_2(mod_2_), index(0), ready(false)
         {
             assert(!source_.empty());
