@@ -18,7 +18,6 @@
 #include <limits>
 #include <stxxl/vector>
 
-
 STXXL_BEGIN_NAMESPACE
 
 template <class ValueType, class VectorType>
@@ -257,8 +256,8 @@ protected:
 public:
     const_deque_iterator() : m_deque(NULL), m_offset(0) { }
 
-    const_deque_iterator(const deque_iterator<deque_type>& it) :
-        m_deque(it.m_deque), m_offset(it.m_offset)
+    const_deque_iterator(const deque_iterator<deque_type>& it)
+        : m_deque(it.m_deque), m_offset(it.m_offset)
     { }
 
     difference_type operator - (const self_type& a) const
