@@ -25,7 +25,6 @@
 #include <stxxl/bits/mng/write_pool.h>
 #include <stxxl/bits/mng/prefetch_pool.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
 #ifndef STXXL_VERBOSE_SEQUENCE
@@ -35,7 +34,7 @@ STXXL_BEGIN_NAMESPACE
 //! \addtogroup stlcont
 //! \{
 
-//! \brief External sequence or deque container without random access. \n
+//! External sequence or deque container without random access. \n
 //! <b> Introduction </b> to sequence container: see \ref tutorial_sequence tutorial. \n
 //! <b> Design and Internals </b> of sequence container: see \ref design_queue
 
@@ -123,11 +122,11 @@ public:
     //! \param D  number of parallel disks, defaulting to the configured number of scratch disks,
     //!           memory consumption will be 2 * D + 2 blocks
     //!           (first and last block, D blocks as write cache, D block for prefetching)
-    explicit sequence(int_type D = -1) :
-        m_size(0),
-        m_owns_pool(true),
-        m_alloc_count(0),
-        m_bm(block_manager::get_instance())
+    explicit sequence(int_type D = -1)
+        : m_size(0),
+          m_owns_pool(true),
+          m_alloc_count(0),
+          m_bm(block_manager::get_instance())
     {
         if (D < 1) D = config::get_instance()->disks_number();
         STXXL_VERBOSE_SEQUENCE("sequence[" << this << "]::sequence(D)");
@@ -141,11 +140,11 @@ public:
     //! \param p_pool_size  number of blocks in the prefetch pool, recommended at least 1
     //! \param blocks2prefetch  defines the number of blocks to prefetch (\c front side),
     //!                          default is number of block in the prefetch pool
-    explicit sequence(unsigned_type w_pool_size, unsigned_type p_pool_size, int blocks2prefetch = -1) :
-        m_size(0),
-        m_owns_pool(true),
-        m_alloc_count(0),
-        m_bm(block_manager::get_instance())
+    explicit sequence(unsigned_type w_pool_size, unsigned_type p_pool_size, int blocks2prefetch = -1)
+        : m_size(0),
+          m_owns_pool(true),
+          m_alloc_count(0),
+          m_bm(block_manager::get_instance())
     {
         STXXL_VERBOSE_SEQUENCE("sequence[" << this << "]::sequence(sizes)");
         m_pool = new pool_type(p_pool_size, w_pool_size);
@@ -158,12 +157,12 @@ public:
     //! \param blocks2prefetch  defines the number of blocks to prefetch (\c front side), default is number of blocks in the prefetch pool
     //!  \warning Number of blocks in the write pool must be at least 2, recommended at least 3
     //!  \warning Number of blocks in the prefetch pool recommended at least 1
-    sequence(pool_type& pool, int blocks2prefetch = -1) :
-        m_size(0),
-        m_owns_pool(false),
-        m_pool(&pool),
-        m_alloc_count(0),
-        m_bm(block_manager::get_instance())
+    sequence(pool_type& pool, int blocks2prefetch = -1)
+        : m_size(0),
+          m_owns_pool(false),
+          m_pool(&pool),
+          m_alloc_count(0),
+          m_bm(block_manager::get_instance())
     {
         STXXL_VERBOSE_SEQUENCE("sequence[" << this << "]::sequence(pool)");
         init(blocks2prefetch);
@@ -562,7 +561,7 @@ public:
 
     //! \}
 
-    /********************************************************************************/
+    /**************************************************************************/
 
     class stream
     {
@@ -693,7 +692,7 @@ public:
 
     //! \}
 
-    /********************************************************************************/
+    /**************************************************************************/
 
     class reverse_stream
     {
