@@ -31,7 +31,6 @@
 #include <stxxl/bits/mng/buf_istream_reverse.h>
 #include <stxxl/bits/mng/buf_ostream.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
 #define STXXL_VERBOSE_VECTOR(msg) STXXL_VERBOSE1("vector[" << static_cast<const void*>(this) << "]::" << msg)
@@ -40,15 +39,16 @@ STXXL_BEGIN_NAMESPACE
 //! \ingroup stllayer
 //! Containers with STL-compatible interface
 
-
 //! \defgroup stlcont_vector vector
 //! \ingroup stlcont
 //! Vector and support classes
 //! \{
 
-template <typename size_type, size_type modulo2, size_type modulo1>
+template <typename SizeType, SizeType modulo2, SizeType modulo1>
 class double_blocked_index
 {
+    typedef SizeType size_type;
+
     static const size_type modulo12 = modulo1 * modulo2;
 
     size_type pos;
@@ -274,10 +274,14 @@ template <typename ValueType, typename AllocStr, typename SizeType, typename Dif
           unsigned BlockSize, typename PagerType, unsigned PageSize>
 class vector_iterator
 {
-    typedef vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> self_type;
-    typedef const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> const_self_type;
+    typedef vector_iterator<ValueType, AllocStr, SizeType,
+                            DiffType, BlockSize, PagerType, PageSize> self_type;
 
-    friend class const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>;
+    typedef const_vector_iterator<ValueType, AllocStr, SizeType,
+                                  DiffType, BlockSize, PagerType, PageSize> const_self_type;
+
+    friend class const_vector_iterator<ValueType, AllocStr, SizeType,
+                                       DiffType, BlockSize, PagerType, PageSize>;
 
 public:
     //! \name Types
@@ -546,10 +550,14 @@ template <typename ValueType, typename AllocStr, typename SizeType, typename Dif
           unsigned BlockSize, typename PagerType, unsigned PageSize>
 class const_vector_iterator
 {
-    typedef const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> self_type;
-    typedef vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> mutable_self_type;
+    typedef const_vector_iterator<ValueType, AllocStr, SizeType, DiffType,
+                                  BlockSize, PagerType, PageSize> self_type;
 
-    friend class vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>;
+    typedef vector_iterator<ValueType, AllocStr, SizeType, DiffType,
+                            BlockSize, PagerType, PageSize> mutable_self_type;
+
+    friend class vector_iterator<ValueType, AllocStr, SizeType, DiffType,
+                                 BlockSize, PagerType, PageSize>;
 
 public:
     //! \name Types
@@ -793,7 +801,7 @@ public:
 
 ////////////////////////////////////////////////////////////////////////////
 
-//! \brief External vector container. \n
+//! External vector container. \n
 //! <b>Introduction</b> to vector container: see \ref tutorial_vector tutorial. \n
 //! <b>Design and Internals</b> of vector container: see \ref design_vector
 //!
@@ -1038,7 +1046,7 @@ public:
         return size_type(m_bids.size()) * block_type::raw_size;
     }
 
-    /*! \brief Reserves at least n elements in external memory.
+    /*! Reserves at least n elements in external memory.
      *
      * If n is less than or equal to capacity(), this call has no
      * effect. Otherwise, it is a request for allocation of additional \b
@@ -1122,7 +1130,7 @@ private:
     void _resize_shrink_capacity(size_type n)
     {
         unsigned_type old_bids_size = m_bids.size();
-        unsigned_type new_bids_size = div_ceil(n, block_type::size);
+        unsigned_type new_bids_size = (unsigned_type)div_ceil(n, block_type::size);
 
         if (new_bids_size > old_bids_size)
         {
@@ -1266,7 +1274,6 @@ public:
         for (unsigned_type i = 0; i < numpages(); ++i)
             m_free_slots.push(i);
 
-
         // allocate blocks equidistantly and in-order
         size_type offset = 0;
         for (bids_container_iterator it = m_bids.begin();
@@ -1706,7 +1713,9 @@ private:
 
     void block_externally_updated(size_type offset) const
     {
-        page_externally_updated(offset / (block_type::size * page_size));
+        page_externally_updated(
+            (unsigned_type)(offset / (block_type::size * page_size))
+            );
     }
 
     void block_externally_updated(const blocked_index_type& offset) const
@@ -1865,25 +1874,25 @@ inline bool operator >= (stxxl::vector<ValueType, PageSize, PagerType, BlockSize
 template <typename ValueType, typename AllocStr, typename SizeType, typename DiffType,
           unsigned BlockSize, typename PagerType, unsigned PageSize>
 bool is_sorted(
-    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> __first,
-    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> __last)
+    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> first,
+    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> last)
 {
     return is_sorted_helper(
-        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(__first),
-        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(__last));
+        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(first),
+        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(last));
 }
 
 template <typename ValueType, typename AllocStr, typename SizeType, typename DiffType,
-          unsigned BlockSize, typename PagerType, unsigned PageSize, typename _StrictWeakOrdering>
+          unsigned BlockSize, typename PagerType, unsigned PageSize, typename StrictWeakOrdering>
 bool is_sorted(
-    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> __first,
-    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> __last,
-    _StrictWeakOrdering __comp)
+    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> first,
+    stxxl::vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize> last,
+    StrictWeakOrdering comp)
 {
     return is_sorted_helper(
-        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(__first),
-        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(__last),
-        __comp);
+        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(first),
+        stxxl::const_vector_iterator<ValueType, AllocStr, SizeType, DiffType, BlockSize, PagerType, PageSize>(last),
+        comp);
 }
 
 ////////////////////////////////////////////////////////////////////////////
@@ -1932,6 +1941,9 @@ public:
     //! construct an iterator for vector_bufreader (for C++11 range-based for loop)
     typedef vector_bufreader_iterator<vector_bufreader> bufreader_iterator;
 
+    //! size of remaining data
+    typedef typename vector_type::size_type size_type;
+
 protected:
     //! iterator to the beginning of the range.
     vector_iterator m_begin;
@@ -1956,7 +1968,8 @@ public:
     //! \param begin iterator to position were to start reading in vector
     //! \param end iterator to position were to end reading in vector
     //! \param nbuffers number of buffers used for overlapped I/O (>= 2*D recommended)
-    vector_bufreader(vector_iterator begin, vector_iterator end, unsigned_type nbuffers = 0)
+    vector_bufreader(vector_iterator begin, vector_iterator end,
+                     unsigned_type nbuffers = 0)
         : m_begin(begin), m_end(end),
           m_bufin(NULL),
           m_nbuffers(nbuffers)
@@ -2050,10 +2063,10 @@ public:
     }
 
     //! Return remaining size.
-    size_t size() const
+    size_type size() const
     {
         assert(m_begin <= m_iter && m_iter <= m_end);
-        return (m_end - m_iter);
+        return (size_type)(m_end - m_iter);
     }
 
     //! Returns true once the whole range has been read.
@@ -2196,6 +2209,9 @@ public:
     //! construct output buffered stream used for overlapped reading
     typedef buf_istream_reverse<block_type, bids_container_iterator> buf_istream_type;
 
+    //! size of remaining data
+    typedef typename vector_type::size_type size_type;
+
 protected:
     //! iterator to the beginning of the range.
     vector_iterator m_begin;
@@ -2217,7 +2233,8 @@ public:
     //! \param begin iterator to position were to start reading in vector
     //! \param end iterator to position were to end reading in vector
     //! \param nbuffers number of buffers used for overlapped I/O (>= 2*D recommended)
-    vector_bufreader_reverse(vector_iterator begin, vector_iterator end, unsigned_type nbuffers = 0)
+    vector_bufreader_reverse(vector_iterator begin, vector_iterator end,
+                             unsigned_type nbuffers = 0)
         : m_begin(begin), m_end(end),
           m_bufin(NULL),
           m_nbuffers(nbuffers)
@@ -2317,10 +2334,10 @@ public:
     }
 
     //! Return remaining size.
-    size_t size() const
+    size_type size() const
     {
         assert(m_begin <= m_iter && m_iter <= m_end);
-        return (m_iter - m_begin);
+        return (size_type)(m_iter - m_begin);
     }
 
     //! Returns true once the whole range has been read.
@@ -2443,7 +2460,12 @@ public:
             // iterator points to end of vector -> double vector's size
 
             if (m_bufout) {
-                m_bufout->flush(); // flush overlap buffers
+                // fixes issue with buf_ostream writing invalid blocks: when
+                // buf_ostream::current_elem advances to next block, flush()
+                // will write to block beyond bid().end.
+                if (m_iter.block_offset() != 0)
+                    m_bufout->flush(); // flushes overlap buffers
+
                 delete m_bufout;
                 m_bufout = NULL;
 
@@ -2558,7 +2580,7 @@ public:
 
 ////////////////////////////////////////////////////////////////////////////
 
-//! \brief External vector type generator.
+//! External vector type generator.
 //!
 //! \tparam ValueType element type of contained objects (POD with no references to internal memory)
 //! \tparam PageSize number of blocks in a page, default: \b 4 (recommended >= D)
