@@ -4,28 +4,31 @@
  *  Part of the STXXL. See http://stxxl.sourceforge.net
  *
  *  Copyright (C) 2008-2009 Andreas Beckmann <beckmann@cs.uni-frankfurt.de>
+ *  Copyright (C) 2013 Timo Bingmann <tb@panthema.net>
  *
  *  Distributed under the Boost Software License, Version 1.0.
  *  (See accompanying file LICENSE_1_0.txt or copy at
  *  http://www.boost.org/LICENSE_1_0.txt)
  **************************************************************************/
 
-#ifndef STXXL_HEADER__DEPRECATED_H
-#define STXXL_HEADER__DEPRECATED_H
+#ifndef STXXL_DEPRECATED_HEADER
+#define STXXL_DEPRECATED_HEADER
 
-#ifdef STXXL_BOOST_CONFIG
- #include <boost/config.hpp>
-#endif
+#include <stxxl/bits/config.h>
 
+// deprecated functions
 
-#ifdef BOOST_MSVC
-  #define _STXXL_DEPRECATED(x) __declspec(deprecated) x
+#if STXXL_NO_DEPRECATED
+// dont issue deprecated warnings for forced instantiation tests -tb
+  #define STXXL_DEPRECATED(x) x
+#elif STXXL_MSVC
+  #define STXXL_DEPRECATED(x) __declspec(deprecated) x
 #elif defined(__GNUG__) && ((__GNUC__ * 10000 + __GNUC_MINOR__ * 100) < 30400)
 // no __attribute__ ((__deprecated__)) in GCC 3.3
-  #define _STXXL_DEPRECATED(x) x
+  #define STXXL_DEPRECATED(x) x
 #else
-  #define _STXXL_DEPRECATED(x) x __attribute__ ((__deprecated__))
+  #define STXXL_DEPRECATED(x) x __attribute__ ((__deprecated__))
 #endif
 
-#endif // !STXXL_HEADER__DEPRECATED_H
+#endif // !STXXL_DEPRECATED_HEADER
 // vim: et:ts=4:sw=4
