@@ -21,10 +21,9 @@
 #include <stxxl/bits/noncopyable.h>
 #include <stxxl/bits/common/types.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
-//! \addtogroup iolayer
+//! \addtogroup reqlayer
 //! \{
 
 class onoff_switch;
@@ -48,12 +47,8 @@ public:
 protected:
     virtual void notify_waiters() = 0;
 
-public:
-    // HACK!
-    virtual void serve() = 0;
-
 protected:
-    virtual void completed() = 0;
+    virtual void completed(bool canceled) = 0;
 
 public:
     //! Suspends calling thread until completion of the request.
