@@ -19,21 +19,20 @@
 #include <stxxl/bits/io/request_with_waiters.h>
 #include <stxxl/bits/namespace.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
-//! \addtogroup fileimpl
+//! \addtogroup reqlayer
 //! \{
 
 //! Request with completion state.
-class request_with_state : public request, public request_with_waiters
+class request_with_state : public request_with_waiters
 {
 protected:
     //! states of request
     //! OP - operating, DONE - request served, READY2DIE - can be destroyed
     enum request_state { OP = 0, DONE = 1, READY2DIE = 2 };
 
-    state<request_state> _state;
+    state<request_state> m_state;
 
 protected:
     request_with_state(
@@ -42,9 +41,9 @@ protected:
         void* buf,
         offset_type off,
         size_type b,
-        request_type t) :
-        request(on_cmpl, f, buf, off, b, t),
-        _state(OP)
+        request_type t)
+        : request_with_waiters(on_cmpl, f, buf, off, b, t),
+          m_state(OP)
     { }
 
 public:
@@ -52,6 +51,9 @@ public:
     void wait(bool measure_time = true);
     bool poll();
     bool cancel();
+
+protected:
+    void completed(bool canceled);
 };
 
 //! \}
