@@ -18,28 +18,38 @@
 
 #include <stxxl/bits/common/mutex.h>
 #include <stxxl/bits/common/onoff_switch.h>
-#include <stxxl/bits/io/request_interface.h>
+#include <stxxl/bits/io/request.h>
 #include <stxxl/bits/namespace.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
-//! \addtogroup fileimpl
+//! \addtogroup reqlayer
 //! \{
 
 //! Request that is aware of threads waiting for it to complete.
-class request_with_waiters : virtual public request_interface
+class request_with_waiters : public request
 {
-    mutex waiters_mutex;
-    std::set<onoff_switch*> waiters;
+    mutex m_waiters_mutex;
+    std::set<onoff_switch*> m_waiters;
 
 protected:
     bool add_waiter(onoff_switch* sw);
     void delete_waiter(onoff_switch* sw);
     void notify_waiters();
-    /*
-    int nwaiters();             // returns number of waiters
-    */
+
+    //! returns number of waiters
+    size_t num_waiters();
+
+public:
+    request_with_waiters(
+        const completion_handler& on_cmpl,
+        file* f,
+        void* buf,
+        offset_type off,
+        size_type b,
+        request_type t)
+        : request(on_cmpl, f, buf, off, b, t)
+    { }
 };
 
 //! \}
