@@ -16,7 +16,6 @@
 #include <stxxl/bits/mng/write_pool.h>
 #include <stxxl/bits/mng/prefetch_pool.h>
 
-
 STXXL_BEGIN_NAMESPACE
 
 //! \addtogroup schedlayer
@@ -43,15 +42,15 @@ public:
     //! Constructs pool.
     //! \param init_size_prefetch initial number of blocks in the prefetch pool
     //! \param init_size_write initial number of blocks in the write pool
-    explicit read_write_pool(size_type init_size_prefetch = 1, size_type init_size_write = 1) :
-        delete_pools(true)
+    explicit read_write_pool(size_type init_size_prefetch = 1, size_type init_size_write = 1)
+        : delete_pools(true)
     {
         w_pool = new write_pool_type(init_size_write);
         p_pool = new prefetch_pool_type(init_size_prefetch);
     }
 
-    STXXL_DEPRECATED(read_write_pool(prefetch_pool_type& p_pool, write_pool_type& w_pool)) :
-        w_pool(&w_pool), p_pool(&p_pool), delete_pools(false)
+    STXXL_DEPRECATED(read_write_pool(prefetch_pool_type& p_pool, write_pool_type& w_pool))
+        : w_pool(&w_pool), p_pool(&p_pool), delete_pools(false)
     { }
 
     void swap(read_write_pool& obj)
@@ -62,7 +61,7 @@ public:
     }
 
     //! Waits for completion of all ongoing requests and frees memory.
-    virtual ~read_write_pool()
+    ~read_write_pool()
     {
         if (delete_pools) {
             delete w_pool;
@@ -157,7 +156,6 @@ public:
 
 STXXL_END_NAMESPACE
 
-
 namespace std {
 
 template <class BlockType>
