@@ -13,7 +13,8 @@
 #ifndef STXXL_NAMESPACE_HEADER
 #define STXXL_NAMESPACE_HEADER
 
-#define __STXXL_BEGIN_NAMESPACE namespace stxxl {
-#define __STXXL_END_NAMESPACE }
+#define STXXL_BEGIN_NAMESPACE namespace stxxl {
+#define STXXL_END_NAMESPACE \
+    }
 
 #endif // !STXXL_NAMESPACE_HEADER
