@@ -15,33 +15,34 @@
 #ifndef STXXL_NONCOPYABLE_HEADER
 #define STXXL_NONCOPYABLE_HEADER
 
-#ifdef STXXL_BOOST_CONFIG
-#include <boost/noncopyable.hpp>
-#endif
-
+#include <stxxl/bits/config.h>
 #include <stxxl/bits/namespace.h>
 
+#if STXXL_BOOST_CONFIG
+  #include <boost/noncopyable.hpp>
+#endif
 
-__STXXL_BEGIN_NAMESPACE
+STXXL_BEGIN_NAMESPACE
 
-#ifdef STXXL_BOOST_CONFIG
+#if STXXL_BOOST_CONFIG
 
 typedef boost::noncopyable noncopyable;
 
 #else
 
-class noncopyable {
+class noncopyable
+{
 protected:
     noncopyable() { }
 
 private:
     // copying and assignment is not allowed
-    noncopyable(const noncopyable &);
-    const noncopyable & operator = (const noncopyable &);
+    noncopyable(const noncopyable&);
+    const noncopyable& operator = (const noncopyable&);
 };
 
 #endif
 
-__STXXL_END_NAMESPACE
+STXXL_END_NAMESPACE
 
 #endif // !STXXL_NONCOPYABLE_HEADER
